@@ -12,7 +12,6 @@ import os
 import re
 import requests
 import shutil
-import six
 import time
 import xml2rfc.log
 import xml2rfc.utils
@@ -55,11 +54,6 @@ class CachingResolver(lxml.etree.Resolver):
                  templates_path=base.default_options.template_dir, verbose=None, quiet=None,
                  no_network=None, network_locs= [
                      'https://bib.ietf.org/public/rfc/',
-                     'https://xml2rfc.ietf.org/public/rfc/',
-                     'https://xml2rfc.tools.ietf.org/public/rfc/',
-                     'http://bib.ietf.org/public/rfc/',
-                     'http://xml2rfc.ietf.org/public/rfc/',
-                     'http://xml2rfc.tools.ietf.org/public/rfc/',
                  ],
                  rfc_number=None, options=base.default_options):
         self.quiet = quiet if quiet != None else options.quiet
@@ -77,7 +71,7 @@ class CachingResolver(lxml.etree.Resolver):
 
         # Get directory of source
         if self.source:
-            if isinstance(self.source, six.string_types):
+            if isinstance(self.source, str):
                 self.source_dir = os.path.abspath(os.path.dirname(self.source))
             else:
                 self.source_dir = os.path.abspath(os.path.dirname(self.source.name))                
@@ -197,9 +191,7 @@ class CachingResolver(lxml.etree.Resolver):
               on the CLI this is set by $XML_LIBRARY, defaulting to 
               ['/usr/share/xml2rfc'].  On the GUI this can be configured
               manually but has the same initial defaults.
-            - NETWORK refers to the online citation library.  On the CLI this
-              is http://xml2rfc.ietf.org/public/rfc/.  On the GUI this 
-              can be configured manually but has the same initial default.
+            - NETWORK refers to the online citation library.
 
             The caches in read_dirs are consulted in sequence order to find the
             request.  If not found, the request will be cached at write_dir.
@@ -234,12 +226,10 @@ class CachingResolver(lxml.etree.Resolver):
                     result = os.path.join(self.source_dir, basename)
                     attempts.append(result)
         else:
-            if self.options and self.options.vocabulary == 'v3':
-                paths = [ request ]
-            elif not request.endswith('.xml'):
-                paths = [ request, request + '.xml' ]
+            if not request.endswith('.xml'):
+                paths = [ request + '.xml', request ]
             else:
-                paths = [ request ]                
+                paths = [ request ]
             if os.path.isabs(paths[0]):
                 # Absolute path, return as-is
                 for path in paths:
@@ -467,7 +457,7 @@ class AnnotatedElement(lxml.etree.ElementBase):
         if value == default:
             return value
         else:
-            return six.text_type(value)
+            return str(value)
 
 class XmlRfcParser:
 
@@ -481,11 +471,6 @@ class XmlRfcParser:
                  cache_path=None, templates_path=base.default_options.template_dir, library_dirs=None, add_xmlns=False,
                  no_network=None, network_locs=[
                      'https://bib.ietf.org/public/rfc/',
-                     'https://xml2rfc.ietf.org/public/rfc/',
-                     'https://xml2rfc.tools.ietf.org/public/rfc/',
-                     'http://bib.ietf.org/public/rfc/',
-                     'http://xml2rfc.ietf.org/public/rfc/',
-                     'http://xml2rfc.tools.ietf.org/public/rfc/',
                  ]
                  ):
         self.options = options
@@ -557,48 +542,43 @@ class XmlRfcParser:
                 text = text.replace(b'<rfc ', b'<rfc xmlns:%s="%s" ' % (b'xi', self.nsmap[b'xi']), 1)
 
         # Get an iterating parser object
-        file = six.BytesIO(text)
-        file.name = self.source
-        context = lxml.etree.iterparse(file,
-                                      dtd_validation=False,
-                                      load_dtd=True,
-                                      attribute_defaults=True,
-                                      no_network=self.no_network,
-                                      remove_comments=remove_comments,
-                                      remove_pis=remove_pis,
-                                      remove_blank_text=True,
-                                      resolve_entities=False,
-                                      strip_cdata=strip_cdata,
-                                      events=("start",),
-                                      tag="rfc",
-                                  )
-        # resolver without knowledge of rfc_number:
-        caching_resolver = CachingResolver(cache_path=self.cache_path,
-                                        library_dirs=self.library_dirs,
-                                        templates_path=self.templates_path,
-                                        source=self.source,
-                                        no_network=self.no_network,
-                                        network_locs=self.network_locs,
-                                        verbose=self.verbose,
-                                        quiet=self.quiet,
-                                        options=self.options,
-                                     )
-        context.resolvers.add(caching_resolver)
+        with io.BytesIO(text) as file:
+            file.name = self.source
+            context = lxml.etree.iterparse(file,
+                                          dtd_validation=False,
+                                          load_dtd=True,
+                                          attribute_defaults=True,
+                                          no_network=self.no_network,
+                                          remove_comments=remove_comments,
+                                          remove_pis=remove_pis,
+                                          remove_blank_text=True,
+                                          resolve_entities=False,
+                                          strip_cdata=strip_cdata,
+                                          events=("start",),
+                                          tag="rfc",
+                                      )
+            # resolver without knowledge of rfc_number:
+            caching_resolver = CachingResolver(cache_path=self.cache_path,
+                                            library_dirs=self.library_dirs,
+                                            templates_path=self.templates_path,
+                                            source=self.source,
+                                            no_network=self.no_network,
+                                            network_locs=self.network_locs,
+                                            verbose=self.verbose,
+                                            quiet=self.quiet,
+                                            options=self.options,
+                                         )
+            context.resolvers.add(caching_resolver)
 
-        # Get hold of the rfc number (if any) in the rfc element, so we can
-        # later resolve the "&rfc.number;" entity.
-        self.rfc_number = None
-        self.format_version = None
-        try:
+            # Get hold of the rfc number (if any) in the rfc element, so we can
+            # later resolve the "&rfc.number;" entity.
+            self.rfc_number = None
+            self.format_version = None
             for action, element in context:
                 if element.tag == "rfc":
                     self.rfc_number = element.attrib.get("number", None)
                     self.format_version = element.attrib.get("version", None)
                     break
-        except ValueError as e:
-            if e.message=="I/O operation on closed file":
-                pass
-
         if self.format_version == "3":
             self.default_dtd_path = None
 
@@ -635,9 +615,9 @@ class XmlRfcParser:
         parser.set_element_class_lookup(element_lookup)
 
         # Parse the XML file into a tree and create an rfc instance
-        file = six.BytesIO(text)
-        file.name = self.source
-        tree = lxml.etree.parse(file, parser)
+        with io.BytesIO(text) as file:
+            file.name = self.source
+            tree = lxml.etree.parse(file, parser)
         xmlrfc = XmlRfc(tree, self.default_dtd_path, nsmap=self.nsmap)
         xmlrfc.source = self.source
 
@@ -657,6 +637,8 @@ class XmlRfcParser:
                 pis = xmlrfc.pis.copy() 
                 if 'include' in pidict and pidict['include']:
                     request = pidict['include']
+                    if xmlrfc.getroot().get('version', '3') in ['3', ]:
+                        xml2rfc.log.warn(f'XInclude should be used instead of PI include for {request}')
                     path = self.cachingResolver.getReferenceRequest(request,
                            # Pass the line number in XML for error bubbling
                            include=True, line_no=getattr(element, 'sourceline', 0))
